@@ -942,7 +942,7 @@ bool Transformation::replaceDependentNameString(const Type *Ty,
   if (Arg.getKind() != TemplateArgument::Type)
     return false;
   QualType ArgQT = Arg.getAsType();
-  ArgQT.getAsStringInternal(Str, Context->getPrintingPolicy());
+  ArgQT.getAsStringInternal(Str, getPrintingPolicy());
   Str += "::";
   Str += IdInfo->getName();
   Typename = true;
@@ -963,7 +963,7 @@ bool Transformation::getTemplateTypeParmString(
   if (Arg.getKind() != TemplateArgument::Type)
     return false;
   QualType ArgQT = Arg.getAsType();
-  ArgQT.getAsStringInternal(Str, Context->getPrintingPolicy());
+  ArgQT.getAsStringInternal(Str, getPrintingPolicy());
   return true;
 }
 
@@ -977,7 +977,7 @@ bool Transformation::getTypedefString(const StringRef &Name,
   Str = "";
   for (DeclContext::decl_iterator I = CXXRD->decls_begin(),
        E = CXXRD->decls_end(); I != E; ++I) {
-    const TypedefDecl *D = dyn_cast<TypedefDecl>(*I);
+    const TypedefNameDecl *D = dyn_cast<TypedefNameDecl>(*I);
     if (!D || (D->getNameAsString() != Name))
       continue;
     const Type *UnderlyingTy = D->getUnderlyingType().getTypePtr();
@@ -1077,7 +1077,7 @@ bool Transformation::getTypeString(const QualType &QT,
 
   case Type::Record:
   case Type::Builtin: { // fall-through
-    QT.getAsStringInternal(Str, Context->getPrintingPolicy());
+    QT.getAsStringInternal(Str, getPrintingPolicy());
     return true;
   }
 
@@ -1119,13 +1119,18 @@ bool Transformation::isInIncludedFile(const Stmt *S) const
   return isInIncludedFile(S->getBeginLoc());
 }
 
-SourceLocation Transformation::getRealLocation(SourceLocation Loc) const
+SourceLocation Transformation::getRealLocation(const SourceLocation& Loc) const
 {
   if (Loc.isMacroID())
     return SrcManager->getExpansionLoc(Loc);
   return Loc;
 }
 
+SourceRange Transformation::getRealLocation(const SourceRange& Range) const
+{
+  return SourceRange(getRealLocation(Range.getBegin()), getRealLocation(Range.getEnd()));
+}
+
 bool Transformation::isDeclaringRecordDecl(const RecordDecl *RD)
 {
   SourceLocation SemiLoc =
@@ -1137,6 +1142,15 @@ bool Transformation::isDeclaringRecordDecl(const RecordDecl *RD)
   return SemiLoc.isInvalid();
 }
 
+clang::PrintingPolicy Transformation::getPrintingPolicy() const {
+  clang::PrintingPolicy Policy = Context->getPrintingPolicy();
+
+  // Do not output (anonymous namespace)::
+  Policy.SuppressUnwrittenScope = true;
+
+  return Policy;
+}
+
 Transformation::~Transformation(void)
 {
   RewriteUtils::Finalize();
