@@ -16,6 +16,7 @@
 #include <cassert>
 #include "llvm/ADT/SmallPtrSet.h"
 #include "clang/AST/ASTConsumer.h"
+#include "clang/AST/PrettyPrinter.h"
 #include "clang/Rewrite/Core/Rewriter.h"
 #include "RewriteUtils.h"
 
@@ -129,6 +130,10 @@ public:
     ToCounter = Counter;
   }
 
+  void setPreprocessor(clang::Preprocessor* PP) {
+    this->PP = PP;
+  }
+
   void setWarnOnCounterOutOfBounds(bool Flag) {
     WarnOnCounterOutOfBounds = Flag;
   }
@@ -316,9 +321,12 @@ protected:
 
   bool isDeclaringRecordDecl(const clang::RecordDecl *RD);
 
+  clang::PrintingPolicy getPrintingPolicy() const;
+
   // If the location is a MacroID, get its expansion location.
   // Otherwise, just return the location.
-  clang::SourceLocation getRealLocation(clang::SourceLocation Loc) const;
+  clang::SourceLocation getRealLocation(const clang::SourceLocation& Loc) const;
+  clang::SourceRange getRealLocation(const clang::SourceRange& Range) const;
 
   const std::string Name;
 
@@ -332,6 +340,8 @@ protected:
 
   clang::SourceManager *SrcManager;
 
+  clang::Preprocessor *PP;
+
   clang::Rewriter TheRewriter;
 
   TransformationError TransError;
