@@ -120,6 +120,9 @@ class TestClangDelta(unittest.TestCase):
         self.check_query_instances('instantiate-template-param/test3.cc', '--query-instances=instantiate-template-param',
                                    'Available transformation instances: 0')
 
+    def test_instantiate_template_param_default_test4(self):
+        self.check_clang_delta('instantiate-template-param/test4.cc', '--transformation=instantiate-template-param --counter=1')
+
     def test_local_to_global_macro(self):
         self.check_clang_delta('local-to-global/macro.c', '--transformation=local-to-global --counter=1')
 
@@ -504,6 +507,12 @@ class TestClangDelta(unittest.TestCase):
     def test_return_void_test7(self):
         self.check_clang_delta('return-void/test7.cc', '--transformation=return-void --counter=1')
 
+    def test_return_void_test8(self):
+        self.check_clang_delta('return-void/test8.cc', '--transformation=return-void --counter=1')
+
+    def test_return_void_test9(self):
+        self.check_clang_delta('return-void/test9.c', '--transformation=return-void --counter=1')
+
     def test_simplify_callexpr_macro(self):
         self.check_clang_delta('simplify-callexpr/macro.c', '--transformation=simplify-callexpr --counter=1')
 
@@ -550,3 +559,39 @@ class TestClangDelta(unittest.TestCase):
     def test_class_to_struct_forward(self):
         self.check_query_instances('class-to-struct/class-to-struct-forward.C', '--query-instances=class-to-struct',
                                    'Available transformation instances: 0')
+
+    def test_class_template_to_class(self):
+        self.check_clang_delta('class-template-to-class/test1.cc', '--transformation=class-template-to-class --counter=1')
+
+    def test_replace_simple_typedef_test1(self):
+        self.check_clang_delta('replace-simple-typedef/test1.cc', '--transformation=replace-simple-typedef --counter=1')
+
+    def test_replace_simple_typedef_test2(self):
+        self.check_clang_delta('replace-simple-typedef/test2.cc', '--transformation=replace-simple-typedef --counter=1')
+
+    def test_member_to_global_test1(self):
+        self.check_clang_delta('member-to-global/test1.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test2(self):
+        self.check_clang_delta('member-to-global/test2.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test3(self):
+        self.check_clang_delta('member-to-global/test3.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test4(self):
+        self.check_clang_delta('member-to-global/test4.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test5(self):
+        self.check_clang_delta('member-to-global/test5.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test6(self):
+        self.check_clang_delta('member-to-global/test6.cc', '--transformation=member-to-global --counter=1')
+
+    def test_member_to_global_test7(self):
+        self.check_clang_delta('member-to-global/test7.cc', '--transformation=member-to-global --counter=1')
+
+    def test_rename_operator_test1(self):
+        self.check_clang_delta('rename-operator/test1.cc', '--transformation=rename-operator --counter=1')
+
+    def test_rename_operator_test2(self):
+        self.check_clang_delta('rename-operator/test2.cc', '--transformation=rename-operator --counter=1')
