@@ -186,7 +186,7 @@ if __name__ == '__main__':
     passes_group = parser.add_mutually_exclusive_group()
     passes_group.add_argument('--pass-group', type=str, choices=get_available_pass_groups(), help='Set of passes used during the reduction')
     passes_group.add_argument('--pass-group-file', type=str, help='JSON file defining a custom pass group')
-    parser.add_argument('--clang-delta-std', type=str, choices=['c++98', 'c++11', 'c++14', 'c++17', 'c++20'], help='Specify clang_delta C++ standard, it can rapidly speed up all clang_delta passes')
+    parser.add_argument('--clang-delta-std', type=str, choices=['c++98', 'c++11', 'c++14', 'c++17', 'c++20', 'c++2b'], help='Specify clang_delta C++ standard, it can rapidly speed up all clang_delta passes')
     parser.add_argument('--clang-delta-preserve-routine', type=str, help='Preserve the given function in replace-function-def-with-decl clang delta pass')
     parser.add_argument('--not-c', action='store_true', help="Don't run passes that are specific to C and C++, use this mode for reducing other languages")
     parser.add_argument('--renaming', action='store_true', help='Enable all renaming passes (that are disabled by default)')
